# To support reload properly, try to access a package var,
# if it's there, reload everything
if "bpy" in locals():
    import importlib
    if "import_svg" in locals():
        importlib.reload(import_svg) # type: ignore


import bpy
from bpy.props import StringProperty
from bpy_extras.io_utils import ImportHelper
from bpy.app.translations import pgettext_tip as tip_
import xml.dom.minidom

from ..mixins import Procedural_Signs_Append_Mixin

class Procedural_Signs_OT_ImportSVG(bpy.types.Operator, ImportHelper, Procedural_Signs_Append_Mixin):
    """Load a SVG file"""
    bl_idname = "procedural_signs.append_svg"
    bl_label = "Import SVG"
    bl_options = {"REGISTER","UNDO","INTERNAL"}

    filename_ext = ".svg"
    filter_glob: StringProperty(default="*.svg", options={'HIDDEN'})

    def execute(self, context):
        from . import import_svg
        filepath=self.filepath
        # error in code should raise exceptions but loading
        # non SVG files can give useful messages.
        do_colormanage = context.scene.display_settings.display_device != 'NONE'
        try:
            collection = import_svg.load_svg(context, filepath, do_colormanage)
            name = collection.name
            objects = collection.objects[:]

            # When importing SVGs it created multiple curve objects.
            # One for each island/svg element. We require only 1 object.
            # So joining all the objects created by importing the SVG 
            bpy.ops.object.select_all(action='DESELECT')
            for obj in objects:
                obj.select_set(True)
                context.view_layer.objects.active = obj
            bpy.ops.object.join()

            svg_object = context.view_layer.objects.active
            svg_object.name = name
            # changed the fill_mode at curve creation time.
            # 4 location in import_svg.py -> in _doCreateGeom

            
            # When importing SVGs it created multiple curve objects.
            # These objects are linked to a new collection which is named as source file
            # We link the SVG object to Sign Collection. So this collection is not required.
            # So unlinking the object and deleting the collection
            for coll in svg_object.users_collection:
                coll.objects.unlink(obj)
            bpy.data.collections.remove(collection)
            svg_object.rotation_euler = (3.14/2,0,0)
            self.setup_objects_with_geometry_nodegroup(context, [svg_object],'_Curve')
        except (xml.parsers.expat.ExpatError, UnicodeEncodeError) as e:
            import traceback
            traceback.print_exc()

            self.report({'WARNING'}, tip_("Unable to parse XML, %s:%s for file %r") % (type(e).__name__, e, filepath))
            return {'CANCELLED'}

        return {'FINISHED'}

classes = [Procedural_Signs_OT_ImportSVG]